@@ -26,6 +26,7 @@ from .animation.movement import *
 from .animation.numbers import *
 from .animation.rotation import *
 from .animation.transform import *
+from .animation.transform_matching_parts import *
 from .animation.update import *
 
 from .renderer.cairo_renderer import *
@@ -50,10 +51,12 @@ from .mobject.numbers import *
 from .mobject.probability import *
 from .mobject.shape_matchers import *
 from .mobject.svg.brace import *
+from .mobject.svg.code_mobject import *
+from .mobject.svg.style_utils import *
 from .mobject.svg.svg_mobject import *
+from .mobject.svg.svg_path import *
 from .mobject.svg.tex_mobject import *
 from .mobject.svg.text_mobject import *
-from .mobject.svg.code_mobject import *
 from .mobject.three_d_utils import *
 from .mobject.three_dimensions import *
 from .mobject.types.image_mobject import *
