@@ -1,4 +1,4 @@
-"A camera converts the mobjects contained in a Scene into an array of pixels."
+"""A camera converts the mobjects contained in a Scene into an array of pixels."""
 
 
 __all__ = ["Camera", "BackgroundColoredVMobjectDisplayer"]
