@@ -8,14 +8,15 @@ Examples
 
     class UsefulAnnotations(Scene):
         def construct(self):
-            m0 = SmallDot()
+            m0 = Dot()
             m1 = AnnotationDot()
             m2 = LabeledDot("ii")
             m3 = LabeledDot(MathTex(r"\alpha").set_color(ORANGE))
-            m4 = CurvedArrow(ORIGIN, 2*LEFT)
-            m5 = CurvedDoubleArrow(ORIGIN, 2*RIGHT)
+            m4 = CurvedArrow(2*LEFT, 2*RIGHT, radius= -5)
+            m5 = CurvedArrow(2*LEFT, 2*RIGHT, radius= 8)
+            m6 = CurvedDoubleArrow(ORIGIN, 2*RIGHT)
 
-            self.add(m0, m1, m2, m3, m4, m5)
+            self.add(m0, m1, m2, m3, m4, m5, m6)
             for i, mobj in enumerate(self.mobjects):
                 mobj.shift(DOWN * (i-3))
 
@@ -54,6 +55,8 @@ __all__ = [
     "Square",
     "RoundedRectangle",
     "Cutout",
+    "Angle",
+    "RightAngle",
 ]
 
 import warnings
@@ -76,11 +79,7 @@ from ..utils.space_ops import get_norm
 from ..utils.space_ops import normalize
 from ..utils.space_ops import rotate_vector
 from ..utils.color import *
-
-DEFAULT_DOT_RADIUS = 0.08
-DEFAULT_SMALL_DOT_RADIUS = 0.04
-DEFAULT_DASH_LENGTH = 0.05
-DEFAULT_ARROW_TIP_LENGTH = 0.35
+from .. import logger
 
 
 class TipableVMobject(VMobject):
@@ -392,6 +391,35 @@ class CurvedDoubleArrow(CurvedArrow):
 
 
 class Circle(Arc):
+    """A circle.
+
+    Parameters
+    ----------
+    color : :class:`~.Colors`, optional
+        The color of the shape.
+    close_new_points : :class:`bool`, optional
+        No purpose.
+    anchors_span_full_range : :class:`bool`, optional
+        No purpose.
+    kwargs : Any
+        Additional arguments to be passed to :class:`Arc`
+
+    Examples
+    --------
+
+    .. manim:: CircleExample
+        :save_last_frame:
+
+        class CircleExample(Scene):
+            def construct(self):
+                circle_1 = Circle(radius=1.0)
+                circle_2 = Circle(radius=1.5, color=GREEN)
+                circle_3 = Circle(radius=1.0, color=BLUE_B, fill_opacity=1)
+
+                circle_group = Group(circle_1, circle_2, circle_3).arrange(buff=1)
+                self.add(circle_group)
+    """
+
     def __init__(
         self, color=RED, close_new_points=True, anchors_span_full_range=False, **kwargs
     ):
@@ -406,6 +434,43 @@ class Circle(Arc):
         )
 
     def surround(self, mobject, dim_to_match=0, stretch=False, buffer_factor=1.2):
+        """Modifies a circle so that it surrounds a given mobject.
+
+        Parameters
+        ----------
+        mobject : :class:`~.Mobject`
+            The mobject that the circle will be surrounding.
+        dim_to_match : :class:`int`, optional
+        buffer_factor :  :class:`float`, optional
+            Scales the circle with respect to the mobject. A `buffer_factor` < 1 makes the circle smaller than the mobject.
+        stretch : :class:`bool`, optional
+            Stretches the circle to fit more tightly around the mobject. Note: Does not work with :class:`Line`
+
+        Examples
+        --------
+
+        .. manim:: CircleSurround
+            :save_last_frame:
+
+            class CircleSurround(Scene):
+                def construct(self):
+                    triangle1 = Triangle()
+                    circle1 = Circle().surround(triangle1)
+                    group1 = Group(triangle1,circle1) # treat the two mobjects as one
+
+                    line2 = Line()
+                    circle2 = Circle().surround(line2, buffer_factor=2.0)
+                    group2 = Group(line2,circle2)
+
+                    # buffer_factor < 1, so the circle is smaller than the square
+                    square3 = Square()
+                    circle3 = Circle().surround(square3, buffer_factor=0.5)
+                    group3 = Group(square3, circle3)
+
+                    group = Group(group1, group2, group3).arrange(buff=1)
+                    self.add(group)
+        """
+
         # Ignores dim_to_match and stretch; result will always be a circle
         # TODO: Perhaps create an ellipse class to handle single-dimension stretching
 
@@ -417,11 +482,71 @@ class Circle(Arc):
         return self.scale(buffer_factor)
 
     def point_at_angle(self, angle):
+        """Returns the position of a point on the circle.
+
+        Parameters
+        ----------
+        angle : class: `float`
+            The angle of the point along the circle in radians.
+
+        Examples
+        --------
+
+        .. manim:: PointAtAngleExample
+            :save_last_frame:
+
+            class PointAtAngleExample(Scene):
+                def construct(self):
+                    circle = Circle(radius=2.0)
+                    p1 = circle.point_at_angle(PI/2)
+                    p2 = circle.point_at_angle(270*DEGREES)
+
+                    s1 = Square(side_length=0.25).move_to(p1)
+                    s2 = Square(side_length=0.25).move_to(p2)
+                    self.add(circle, s1, s2)
+
+        Returns
+        -------
+        :class:`numpy.ndarray`
+            The location of the point along the circle's circumference.
+        """
+
         start_angle = angle_of_vector(self.points[0] - self.get_center())
         return self.point_from_proportion((angle - start_angle) / TAU)
 
 
 class Dot(Circle):
+    """A circle with a very small radius.
+
+    Parameters
+    ----------
+    point : Union[:class:`list`, :class:`numpy.ndarray`], optional
+        The location of the dot.
+    radius : Optional[:class:`float`]
+        The radius of the dot.
+    stroke_width : :class:`float`, optional
+        The thickness of the outline of the dot.
+    fill_opacity : :class:`float`, optional
+        The opacity of the dot's fill_colour
+    color : :class:`~.Colors`, optional
+        The color of the dot.
+    kwargs : Any
+        Additional arguments to be passed to :class:`Circle`
+
+    Examples
+    --------
+
+    .. manim:: DotExample
+        :save_last_frame:
+
+        class DotExample(Scene):
+            def construct(self):
+                dot1 = Dot(point=LEFT, radius=0.08)
+                dot2 = Dot(point=ORIGIN)
+                dot3 = Dot(point=RIGHT)
+                self.add(dot1,dot2,dot3)
+    """
+
     def __init__(
         self,
         point=ORIGIN,
@@ -443,11 +568,13 @@ class Dot(Circle):
 
 
 class SmallDot(Dot):
-    """
-    A dot with small radius
-    """
+    """Deprecated - A dot with small radius"""
 
     def __init__(self, radius=DEFAULT_SMALL_DOT_RADIUS, **kwargs):
+        logger.warning(
+            "SmallDot has been deprecated and will be removed in a future release. "
+            "Use Dot instead."
+        )
         Dot.__init__(self, radius=radius, **kwargs)
 
 
@@ -526,6 +653,31 @@ class LabeledDot(Dot):
 
 
 class Ellipse(Circle):
+    """A circular shape; oval, circle.
+
+    Parameters
+    ----------
+    width : :class:`float`, optional
+       The horizontal width of the ellipse.
+    height : :class:`float`, optional
+       The vertical height of the ellipse.
+    kwargs : Any
+       Additional arguments to be passed to :class:`Circle`
+
+    Examples
+    --------
+
+    .. manim:: EllipseExample
+        :save_last_frame:
+
+        class EllipseExample(Scene):
+            def construct(self):
+                ellipse_1 = Ellipse(width=2.0, height=4.0, color=BLUE_B)
+                ellipse_2 = Ellipse(width=4.0, height=1.0, color=BLUE_D)
+                ellipse_group = Group(ellipse_1,ellipse_2).arrange(buff=1)
+                self.add(ellipse_group)
+    """
+
     def __init__(self, width=2, height=1, **kwargs):
         Circle.__init__(self, **kwargs)
         self.stretch_to_fit_width(width)
@@ -706,7 +858,20 @@ class Line(TipableVMobject):
 
 
 class DashedLine(Line):
-    """A dashed Line.
+    """A dashed :class:`Line`.
+
+    Parameters
+    ----------
+    args : Any
+        Arguments to be passed to :class:`Line`
+    dash_length : :class:`float`, optional
+        The length of each individual dash of the line.
+    dash_spacing : Optional[:class:`float`]
+        No purpose.
+    positive_space_ratio : :class:`float`, optional
+        The ratio of empty space to dash space. Range of 0-1.
+    kwargs : Any
+        Additional arguments to be passed to :class:`Line`
 
     Examples
     --------
@@ -715,9 +880,17 @@ class DashedLine(Line):
 
         class DashedLineExample(Scene):
             def construct(self):
-                dashed_line = DashedLine(config.frame_width/2*LEFT, 4*RIGHT)
-                self.add(dashed_line)
+                # dash_length increased
+                dashed_1 = DashedLine(config.left_side, config.right_side, dash_length=2.0).shift(UP*2)
+                # normal
+                dashed_2 = DashedLine(config.left_side, config.right_side)
+                # positive_space_ratio decreased
+                dashed_3 = DashedLine(config.left_side, config.right_side, positive_space_ratio=0.1).shift(DOWN*2)
+                self.add(dashed_1, dashed_2, dashed_3)
 
+    See Also
+    --------
+    :class:`~.DashedVMobject`
     """
 
     def __init__(
@@ -734,15 +907,25 @@ class DashedLine(Line):
         Line.__init__(self, *args, **kwargs)
         dashes = DashedVMobject(
             self,
-            num_dashes=self.calculate_num_dashes(positive_space_ratio),
+            num_dashes=self.calculate_num_dashes(),
             positive_space_ratio=positive_space_ratio,
         )
         self.clear_points()
         self.add(*dashes)
 
-    def calculate_num_dashes(self, positive_space_ratio):
+    def calculate_num_dashes(self) -> int:
+        """Returns the number of dashes in the dashed line.
+
+        Examples
+        --------
+        ::
+
+            >>> DashedLine().calculate_num_dashes()
+            20
+        """
+
         try:
-            full_length = self.dash_length / positive_space_ratio
+            full_length = self.dash_length / self.positive_space_ratio
             return int(np.ceil(self.get_length() / full_length))
         except ZeroDivisionError:
             return 1
@@ -750,26 +933,99 @@ class DashedLine(Line):
     def calculate_positive_space_ratio(self):
         return fdiv(self.dash_length, self.dash_length + self.dash_spacing)
 
-    def get_start(self):
+    def get_start(self) -> np.ndarray:
+        """Returns the start point of the line.
+
+        Examples
+        --------
+        ::
+
+            >>> DashedLine().get_start()
+            array([-1.,  0.,  0.])
+        """
+
         if len(self.submobjects) > 0:
             return self.submobjects[0].get_start()
         else:
             return Line.get_start(self)
 
-    def get_end(self):
+    def get_end(self) -> np.ndarray:
+        """Returns the end point of the line.
+
+        Examples
+        --------
+        ::
+
+            >>> DashedLine().get_end()
+            array([0.99871795, 0.        , 0.        ])
+        """
+
         if len(self.submobjects) > 0:
             return self.submobjects[-1].get_end()
         else:
             return Line.get_end(self)
 
-    def get_first_handle(self):
+    def get_first_handle(self) -> np.ndarray:
+        """Returns the point of the first handle.
+
+        Examples
+        --------
+        ::
+
+            >>> DashedLine().get_first_handle()
+            array([-0.98333333,  0.        ,  0.        ])
+        """
+
         return self.submobjects[0].points[1]
 
-    def get_last_handle(self):
+    def get_last_handle(self) -> np.ndarray:
+        """Returns the point of the last handle.
+
+        Examples
+        --------
+        ::
+
+            >>> DashedLine().get_last_handle()
+            array([0.98205128, 0.        , 0.        ])
+        """
+
         return self.submobjects[-1].points[-2]
 
 
 class TangentLine(Line):
+    """Constructs a line tangent to a :class:`~.VMobject` at a specific point.
+
+    Parameters
+    ----------
+    vmob : :class:`~.VMobject`
+        The VMobject on which the tangent line is drawn.
+    alpha : :class:`float`
+        How far along the shape that the line will be constructed. range: 0-1.
+    length : :class:`float`, optional
+        Length of the tangent line.
+    d_alpha: :class:`float`, optional
+        The ``dx`` value
+    kwargs : Any
+        Additional arguments to be passed to :class:`Line`
+
+    Examples
+    --------
+
+    .. manim:: TangentLineExample
+        :save_last_frame:
+
+        class TangentLineExample(Scene):
+            def construct(self):
+                circle = Circle(radius=2)
+                line_1 = TangentLine(circle, alpha=0.0, length=4, color=BLUE_D) # right
+                line_2 = TangentLine(circle, alpha=0.4, length=4, color=GREEN) # top left
+                self.add(circle, line_1, line_2)
+
+    See Also
+    --------
+    :meth:`~.VMobject.point_from_proportion`
+    """
+
     def __init__(self, vmob, alpha, length=1, d_alpha=1e-6, **kwargs):
         self.length = length
         self.d_alpha = d_alpha
@@ -783,6 +1039,37 @@ class TangentLine(Line):
 
 
 class Elbow(VMobject):
+    """Two lines that create a right angle about each other: L-shape.
+
+    Parameters
+    ----------
+    width : :class:`float`, optional
+        The length of the elbow's sides.
+    angle : :class:`float`, optional
+        The rotation of the elbow.
+    kwargs : Any
+        Additional arguments to be passed to :class:`~.VMobject`
+
+    Examples
+    --------
+
+    .. manim:: ElbowExample
+        :save_last_frame:
+
+        class ElbowExample(Scene):
+            def construct(self):
+                elbow_1 = Elbow()
+                elbow_2 = Elbow(width=2.0)
+                elbow_3 = Elbow(width=2.0, angle=5*PI/4)
+
+                elbow_group = Group(elbow_1, elbow_2, elbow_3).arrange(buff=1)
+                self.add(elbow_group)
+
+    See Also
+    --------
+    :class:`RightAngle`
+    """
+
     def __init__(self, width=0.2, angle=0, **kwargs):
         self.angle = angle
         VMobject.__init__(self, **kwargs)
@@ -792,6 +1079,57 @@ class Elbow(VMobject):
 
 
 class Arrow(Line):
+    """An arrow.
+
+    Parameters
+    ----------
+    args : Any
+        Arguments to be passed to :class:`Line`.
+    stroke_width : :class:`float`, optional
+        The thickness of the arrow. Influenced by :attr:`max_stroke_width_to_length_ratio`.
+    buff : :class:`float`, optional
+        The distance of the arrow from its start and end points.
+    max_tip_length_to_length_ratio : :class:`float`, optional
+        :attr:`tip_length` scales with the length of the arrow. Increasing this ratio raises the max value of :attr:`tip_length`.
+    max_stroke_width_to_length_ratio : :class:`float`, optional
+        :attr:`stroke_width` scales with the length of the arrow. Increasing this ratio ratios the max value of :attr:`stroke_width`.
+    preserve_tip_size_when_scaling : :class:`bool`, optional
+        No purpose.
+    kwargs : Any
+        Additional arguments to be passed to :class:`Line`.
+
+    Examples
+    --------
+
+    .. manim:: ArrowExample
+        :save_last_frame:
+
+        from manim.mobject.geometry import ArrowSquareTip
+        class ArrowExample(Scene):
+            def construct(self):
+                arrow_1 = Arrow(start=RIGHT, end=LEFT, color=GOLD)
+                arrow_2 = Arrow(start=RIGHT, end=LEFT, color=GOLD, tip_shape=ArrowSquareTip).shift(DOWN)
+                g1 = Group(arrow_1, arrow_2)
+
+                # the effect of buff
+                square = Square(color=MAROON_A)
+                arrow_3 = Arrow(start=LEFT, end=RIGHT)
+                arrow_4 = Arrow(start=LEFT, end=RIGHT, buff=0).next_to(arrow_1, UP)
+                g2 = Group(arrow_3, arrow_4, square)
+
+                # a shorter arrow has a shorter tip and smaller stroke width
+                arrow_5 = Arrow(start=ORIGIN, end=config.top).shift(LEFT * 4)
+                arrow_6 = Arrow(start=config.top + DOWN, end=config.top).shift(LEFT * 3)
+                g3 = Group(arrow_5, arrow_6)
+
+                self.add(Group(g1, g2, g3).arrange(buff=2))
+
+    See Also
+    --------
+    :class:`ArrowTip`
+    :class:`CurvedArrow`
+    """
+
     def __init__(
         self,
         *args,
@@ -802,12 +1140,8 @@ class Arrow(Line):
         preserve_tip_size_when_scaling=True,
         **kwargs
     ):
-        self.max_tip_length_to_length_ratio = (
-            max_tip_length_to_length_ratio  # is this used anywhere
-        )
-        self.max_stroke_width_to_length_ratio = (
-            max_stroke_width_to_length_ratio  # is this used anywhere
-        )
+        self.max_tip_length_to_length_ratio = max_tip_length_to_length_ratio
+        self.max_stroke_width_to_length_ratio = max_stroke_width_to_length_ratio
         self.preserve_tip_size_when_scaling = (
             preserve_tip_size_when_scaling  # is this used anywhere
         )
@@ -868,19 +1202,42 @@ class Arrow(Line):
             self.add_tip(tip=old_tips[1], at_start=True)
         return self
 
-    def get_normal_vector(self):
+    def get_normal_vector(self) -> np.ndarray:
+        """Returns the normal of a vector.
+
+        Examples
+        --------
+        ::
+
+            >>> Arrow().get_normal_vector() + 0. # add 0. to avoid negative 0 in output
+            array([ 0.,  0., -1.])
+        """
+
         p0, p1, p2 = self.tip.get_start_anchors()[:3]
         return normalize(np.cross(p2 - p1, p1 - p0))
 
     def reset_normal_vector(self):
+        """Resets the normal of a vector"""
         self.normal_vector = self.get_normal_vector()
         return self
 
-    def get_default_tip_length(self):
+    def get_default_tip_length(self) -> float:
+        """Returns the default tip_length of the arrow.
+
+        Examples
+        --------
+
+        ::
+
+            >>> Arrow().get_default_tip_length()
+            0.35
+        """
+
         max_ratio = self.max_tip_length_to_length_ratio
         return min(self.tip_length, max_ratio * self.get_length())
 
     def set_stroke_width_from_length(self):
+        """Used internally. Sets stroke width based on length."""
         max_ratio = self.max_stroke_width_to_length_ratio
         self.set_stroke(
             width=min(self.initial_stroke_width, max_ratio * self.get_length()),
@@ -890,6 +1247,31 @@ class Arrow(Line):
 
 
 class Vector(Arrow):
+    """A vector specialized for use in graphs.
+
+    Parameters
+    ----------
+    direction : Union[:class:`list`, :class:`numpy.ndarray`]
+        The direction of the arrow.
+    buff : :class:`float`
+         The distance of the vector from its endpoints.
+    kwargs : Any
+        Additional arguments to be passed to :class:`Arrow`
+
+    Examples
+    --------
+
+    .. manim:: VectorExample
+        :save_last_frame:
+
+        class VectorExample(Scene):
+            def construct(self):
+                plane = NumberPlane()
+                vector_1 = Vector([1,2])
+                vector_2 = Vector([-5,-2])
+                self.add(plane, vector_1, vector_2)
+    """
+
     def __init__(self, direction=RIGHT, buff=0, **kwargs):
         self.buff = buff
         if len(direction) == 2:
@@ -898,6 +1280,36 @@ class Vector(Arrow):
 
 
 class DoubleArrow(Arrow):
+    """An arrow with tips on both ends.
+
+    Parameters
+    ----------
+    args : Any
+        Arguments to be passed to :class:`Arrow`
+    kwargs : Any
+        Additional arguments to be passed to :class:`Arrow`
+
+    Examples
+    --------
+
+    .. manim:: DoubleArrowExample
+        :save_last_frame:
+
+        from manim.mobject.geometry import ArrowCircleFilledTip
+        class DoubleArrowExample(Scene):
+            def construct(self):
+                circle = Circle(radius=2.0)
+                d_arrow = DoubleArrow(start=circle.get_left(), end=circle.get_right())
+                d_arrow_2 = DoubleArrow(tip_shape_end=ArrowCircleFilledTip, tip_shape_start=ArrowCircleFilledTip)
+                group = Group(Group(circle, d_arrow), d_arrow_2).arrange(UP, buff=1)
+                self.add(group)
+
+    See Also
+    --------
+    :class:`ArrowTip`
+    :class:`CurvedDoubleArrow`
+    """
+
     def __init__(self, *args, **kwargs):
         if "tip_shape_end" in kwargs:
             kwargs["tip_shape"] = kwargs.pop("tip_shape_end")
@@ -935,15 +1347,97 @@ class CubicBezier(VMobject):
 
 
 class Polygon(VMobject):
+    """A shape created by defining its vertices.
+
+    Parameters
+    ----------
+    vertices : :class:`list`
+        The vertices of the mobject. The first one is repeated to close the shape. Must define 3-dimensions: ``[x,y,z]``
+    color : :class:`~.Colors`, optional
+        The color of the polygon.
+    kwargs : Any
+        Additional arguments to be passed to :class:`.~VMobject`
+
+    Examples
+    --------
+
+    .. manim:: PolygonExample
+        :save_last_frame:
+
+        class PolygonExample(Scene):
+            def construct(self):
+                isosceles = Polygon([-5, 1.5, 0], [-2, 1.5, 0], [-3.5, -2, 0])
+                position_list = [
+                    [4, 1, 0],  # middle right
+                    [4, -2.5, 0],  # bottom right
+                    [0, -2.5, 0],  # bottom left
+                    [0, 3, 0],  # top left
+                    [2, 1, 0],  # middle
+                    [4, 3, 0],  # top right
+                ]
+                square_and_triangles = Polygon(*position_list, color=PURPLE_B)
+                self.add(isosceles, square_and_triangles)
+    """
+
     def __init__(self, *vertices, color=BLUE, **kwargs):
         VMobject.__init__(self, color=color, **kwargs)
         # There are actually four corners, and the first one is repeated twice to form the four vertices.
         self.set_points_as_corners([*vertices, vertices[0]])
 
     def get_vertices(self):
+        """Gets the vertices of the polygon.
+
+        Examples
+        --------
+        ::
+
+            >>> sq = Square()
+            >>> points = sq.get_vertices()
+            >>> points
+            array([[-1.,  1.,  0.],
+                   [ 1.,  1.,  0.],
+                   [ 1., -1.,  0.],
+                   [-1., -1.,  0.]])
+
+        Returns
+        -------
+        :class:`numpy.ndarray`
+            Returns a list of the coordinates of polygon's vertices.
+        """
+
         return self.get_start_anchors()
 
     def round_corners(self, radius=0.5):
+        """Rounds off the corners of the polygon.
+
+        Parameters
+        ----------
+        radius : :class:`float`, optional
+            The curvature of the corners of the polygon.
+
+        Examples
+        --------
+
+        .. manim:: PolygonRoundCorners
+            :save_as_gif:
+
+            class PolygonRoundCorners(Scene):
+                def construct(self):
+                    points = [[-4, -2, 0], [-2, 2, 0], [4, 2, 0], [2, -2, 0]]
+                    parallelogram = Polygon(*points, stroke_color=LIGHT_PINK)
+                    rounded_1 = Polygon(*points, stroke_color=LIGHT_PINK).round_corners(radius=0.5)
+                    rounded_2 = Polygon(*points, stroke_color=LIGHT_PINK).round_corners(radius=1.5)
+
+                    self.play(Transform(parallelogram, rounded_1))
+                    self.wait(0.5)
+                    self.play(Transform(parallelogram, rounded_2))
+                    self.wait(0.5)
+
+        See Also
+        --------
+        :class:`RoundedRectangle`
+        """
+
         vertices = self.get_vertices()
         arcs = []
         for v1, v2, v3 in adjacent_n_tuples(vertices, 3):
@@ -979,6 +1473,33 @@ class Polygon(VMobject):
 
 
 class RegularPolygon(Polygon):
+    """An n-sided regular polygon.
+
+    Parameters
+    ----------
+    n : :class:`int`
+        The number of sides of the polygon.
+    start_angle : Optional[:class:`float`]
+        The angle at which the polygon is rotated.
+    kwargs : Any
+        Additional arguments to be passed to :class:`Polygon`
+
+    Examples
+    --------
+
+    .. manim:: RegularPolygonExample
+        :save_last_frame:
+
+        class RegularPolygonExample(Scene):
+            def construct(self):
+                poly_1 = RegularPolygon(n=6)
+                poly_2 = RegularPolygon(n=6, start_angle=30*DEGREES, color=GREEN)
+                poly_3 = RegularPolygon(n=10, color=RED)
+
+                poly_group = Group(poly_1, poly_2, poly_3).scale(1.5).arrange(buff=1)
+                self.add(poly_group)
+    """
+
     def __init__(self, n=6, start_angle=None, **kwargs):
         self.start_angle = start_angle
         if self.start_angle is None:
@@ -1062,7 +1583,7 @@ class ArcPolygon(VMobject):
                                             {'angle': 20*DEGREES, 'color': BLUE},
                                             {'radius': 1}])
                 ap_group = VGroup(ap1, ap2, ap3, ap4).arrange()
-                self.play(*[ShowCreation(ap) for ap in [ap1, ap2, ap3, ap4]])
+                self.play(*[Create(ap) for ap in [ap1, ap2, ap3, ap4]])
                 self.wait()
 
     For further examples see :class:`ArcPolygonFromArcs`.
@@ -1163,7 +1684,7 @@ class ArcPolygonFromArcs(VMobject):
     after the arcpolygon has been initialized.
 
     Also both the arcs contained in an :class:`~.ArcPolygonFromArcs`, as well as the
-    arcpolygon itself are drawn, which affects draw time in :class:`~.ShowCreation`
+    arcpolygon itself are drawn, which affects draw time in :class:`~.Create`
     for example. In most cases the arcs themselves don't
     need to be drawn, in which case they can be passed as invisible.
 
@@ -1230,11 +1751,64 @@ class ArcPolygonFromArcs(VMobject):
 
 
 class Triangle(RegularPolygon):
+    """An equilateral triangle.
+
+    Parameters
+    ----------
+    kwargs : Any
+        Additonal arguments to be passed to :class:`RegularPolygon`
+
+    Examples
+    --------
+
+    .. manim:: TriangleExample
+        :save_last_frame:
+
+        class TriangleExample(Scene):
+            def construct(self):
+                triangle_1 = Triangle()
+                triangle_2 = Triangle().scale(2).rotate(60*DEGREES)
+                tri_group = Group(triangle_1, triangle_2).arrange(buff=1)
+                self.add(tri_group)
+    """
+
     def __init__(self, **kwargs):
         RegularPolygon.__init__(self, n=3, **kwargs)
 
 
 class Rectangle(Polygon):
+    """A quadrilateral with two sets of parallel sides.
+
+    Parameters
+    ----------
+    color : :class:`~.Colors`, optional
+        The color of the rectangle.
+    height : :class:`float`, optional
+        The vertical height of the rectangle.
+    width : :class:`float`, optional
+        The horizontal width of the rectangle.
+    mark_paths_closed : :class:`bool`, optional
+        No purpose.
+    close_new_points : :class:`bool`, optional
+        No purpose.
+    kwargs : Any
+        Additional arguments to be passed to :class:`Polygon`
+
+    Examples
+    ----------
+
+    .. manim:: RectangleExample
+        :save_last_frame:
+
+        class RectangleExample(Scene):
+            def construct(self):
+                rect1 = Rectangle(width=4.0, height=2.0)
+                rect2 = Rectangle(width=1.0, height=4.0)
+
+                rects = Group(rect1,rect2).arrange(buff=1)
+                self.add(rects)
+    """
+
     def __init__(
         self,
         color=WHITE,
@@ -1252,12 +1826,59 @@ class Rectangle(Polygon):
 
 
 class Square(Rectangle):
+    """A rectangle with equal side lengths.
+
+    Parameters
+    ----------
+    side_length : :class:`float`, optional
+        The length of the sides of the square.
+    kwargs : Any
+        Additional arguments to be passed to :class:`Square`
+
+    Examples
+    --------
+
+    .. manim:: SquareExample
+        :save_last_frame:
+
+        class SquareExample(Scene):
+            def construct(self):
+                square_1 = Square(side_length=2.0).shift(DOWN)
+                square_2 = Square(side_length=1.0).next_to(square_1, direction=UP)
+                square_3 = Square(side_length=0.5).next_to(square_2, direction=UP)
+                self.add(square_1, square_2, square_3)
+    """
+
     def __init__(self, side_length=2.0, **kwargs):
         self.side_length = side_length
         Rectangle.__init__(self, height=side_length, width=side_length, **kwargs)
 
 
 class RoundedRectangle(Rectangle):
+    """A rectangle with rounded corners.
+
+    Parameters
+    ----------
+    corner_radius : :class:`float`, optional
+        The curvature of the corners of the rectangle.
+    kwargs : Any
+        Additional arguments to be passed to :class:`Rectangle`
+
+    Examples
+    --------
+
+    .. manim:: RoundedRectangleExample
+        :save_last_frame:
+
+        class RoundedRectangleExample(Scene):
+            def construct(self):
+                rect_1 = RoundedRectangle(corner_radius=0.5)
+                rect_2 = RoundedRectangle(corner_radius=1.5, height=4.0, width=4.0)
+
+                rect_group = Group(rect_1, rect_2).arrange(buff=1)
+                self.add(rect_group)
+    """
+
     def __init__(self, corner_radius=0.5, **kwargs):
         self.corner_radius = corner_radius
         Rectangle.__init__(self, **kwargs)
@@ -1303,7 +1924,7 @@ class ArrowTip(VMobject):
         >>> from manim import Scene
         >>> class CustomTipExample(Scene):
         ...     def construct(self):
-        ...         self.play(ShowCreation(arr))
+        ...         self.play(Create(arr))
 
     Using a class inherited from :class:`ArrowTip` to get a non-filled
     tip is a shorthand to manually specifying the arrow tip style as follows::
@@ -1554,3 +2175,243 @@ class Cutout(VMobject):
             sub_direction = "CW"
         for mobject in mobjects:
             self.append_points(mobject.force_direction(sub_direction).get_points())
+
+
+class Angle(Arc, Elbow):
+    """A circular arc or elbow-type mobject representing an angle of two lines.
+
+    Parameters
+    ----------
+    line1 : :class:`Line`
+        The first line.
+    line2 : :class:`Line`
+        The second line.
+    radius : :class:`float`
+        The radius of the :class:`Arc`.
+    quadrant : Sequence[:class:`int`]
+        A sequence of two :class:`int` numbers determining which of the 4 quadrants should be used.
+        The first value indicates whether to anchor the arc on the first line closer to the end point (1)
+        or start point (-1), and the second value functions similarly for the end (1) or start (-1) of the second line.
+        Possibilities: (1,1), (-1,1), (1,-1), (-1,-1).
+    other_angle : :class:`bool`
+        Toggles between the two possible angles defined by two points and an arc center. If set to
+        False (default), the arc will always go counterclockwise from the point on line1 until
+        the point on line2 is reached. If set to True, the angle will go clockwise from line1 to line2.
+    dot : :class:`bool`
+        Allows for a :class:`Dot` in the arc. Mainly used as an convention to indicate a right angle.
+        The dot can be customized in the next three parameters.
+    dot_radius : :class:`float`
+        The radius of the :class:`Dot`. If not specified otherwise, this radius will be 1/10 of the arc radius.
+    dot_distance : :class:`float`
+        Relative distance from the center to the arc: 0 puts the dot in the center and 1 on the arc itself.
+    dot_color : :class:`~.Colors`
+        The color of the :class:`Dot`.
+    elbow : :class:`bool`
+        Produces an elbow-type mobject indicating a right angle, see :class:`RightAngle` for more information
+        and a shorthand.
+    **kwargs
+        Further keyword arguments that are passed to the constructor of :class:`Arc` or :class:`Elbow`.
+
+    Examples
+    --------
+    The first example shows some right angles with a dot in the middle while the second example shows
+    all 8 possible angles defined by two lines.
+
+    .. manim:: RightArcAngleExample
+        :save_last_frame:
+
+        class RightArcAngleExample(Scene):
+            def construct(self):
+                line1 = Line( LEFT, RIGHT )
+                line2 = Line( DOWN, UP )
+                rightarcangles = [
+                    Angle(line1, line2, dot=True),
+                    Angle(line1, line2, radius=0.4, quadrant=(1,-1), dot=True, other_angle=True),
+                    Angle(line1, line2, radius=0.5, quadrant=(-1,1), stroke_width=8, dot=True, dot_color=YELLOW, dot_radius=0.04, other_angle=True),
+                    Angle(line1, line2, radius=0.7, quadrant=(-1,-1), color=RED, dot=True, dot_color=GREEN, dot_radius=0.08),
+                ]
+                line_list = VGroup( *[VGroup() for k in range(4)] )
+                for k in range(4):
+                    linea = line1.copy()
+                    lineb = line2.copy()
+                    line_list[k].add( linea )
+                    line_list[k].add( lineb )
+                    line_list[k].add( rightarcangles[k] )
+                line_list.arrange_in_grid(buff=1.5)
+                self.add(
+                    line_list
+                )
+
+    .. manim:: AngleExample
+        :save_last_frame:
+
+        class AngleExample(Scene):
+            def construct(self):
+                line1 = Line( LEFT + (1/3) * UP, RIGHT + (1/3) * DOWN )
+                line2 = Line( DOWN + (1/3) * RIGHT, UP + (1/3) * LEFT )
+                angles = [
+                    Angle(line1, line2),
+                    Angle(line1, line2, radius=0.4, quadrant=(1,-1), other_angle=True),
+                    Angle(line1, line2, radius=0.5, quadrant=(-1,1), stroke_width=8, other_angle=True),
+                    Angle(line1, line2, radius=0.7, quadrant=(-1,-1), color=RED),
+                    Angle(line1, line2, other_angle=True),
+                    Angle(line1, line2, radius=0.4, quadrant=(1,-1)),
+                    Angle(line1, line2, radius=0.5, quadrant=(-1,1), stroke_width=8),
+                    Angle(line1, line2, radius=0.7, quadrant=(-1,-1), color=RED, other_angle=True),
+                ]
+                line_list = VGroup( *[VGroup() for k in range(8)] )
+                for k in range(8):
+                    linea = line1.copy()
+                    lineb = line2.copy()
+                    line_list[k].add( linea )
+                    line_list[k].add( lineb )
+                    line_list[k].add( angles[k] )
+                line_list.arrange_in_grid(n_rows=2, n_cols=4, buff=1.5)
+                self.add(
+                    line_list
+                )
+
+    """
+
+    def __init__(
+        self,
+        line1,
+        line2,
+        radius=None,
+        quadrant=(1, 1),
+        other_angle=False,
+        dot=False,
+        dot_radius=None,
+        dot_distance=0.55,
+        dot_color=WHITE,
+        elbow=False,
+        **kwargs
+    ):
+        self.quadrant = quadrant
+        self.dot_distance = dot_distance
+        self.elbow = elbow
+        inter = line_intersection(
+            [line1.get_start(), line1.get_end()], [line2.get_start(), line2.get_end()]
+        )
+
+        if radius is None:
+            if quadrant[0] == 1:
+                dist_1 = np.linalg.norm(line1.get_end() - inter)
+            else:
+                dist_1 = np.linalg.norm(line1.get_start() - inter)
+            if quadrant[1] == 1:
+                dist_2 = np.linalg.norm(line2.get_end() - inter)
+            else:
+                dist_2 = np.linalg.norm(line2.get_start() - inter)
+            if np.minimum(dist_1, dist_2) < 0.6:
+                radius = (2 / 3) * np.minimum(dist_1, dist_2)
+            else:
+                radius = 0.4
+        else:
+            self.radius = radius
+
+        anchor_angle_1 = inter + quadrant[0] * radius * line1.get_unit_vector()
+        anchor_angle_2 = inter + quadrant[1] * radius * line2.get_unit_vector()
+
+        if elbow:
+            anchor_middle = (
+                inter
+                + quadrant[0] * radius * line1.get_unit_vector()
+                + quadrant[1] * radius * line2.get_unit_vector()
+            )
+            Elbow.__init__(self, **kwargs)
+            self.set_points_as_corners([anchor_angle_1, anchor_middle, anchor_angle_2])
+        else:
+            angle_1 = angle_of_vector(anchor_angle_1 - inter)
+            angle_2 = angle_of_vector(anchor_angle_2 - inter)
+
+            if not other_angle:
+                start_angle = angle_1
+                if angle_2 > angle_1:
+                    angle_fin = angle_2 - angle_1
+                else:
+                    angle_fin = 2 * np.pi - (angle_1 - angle_2)
+            else:
+                start_angle = angle_1
+                if angle_2 < angle_1:
+                    angle_fin = -angle_1 + angle_2
+                else:
+                    angle_fin = -2 * np.pi + (angle_2 - angle_1)
+
+            Arc.__init__(
+                self,
+                radius=radius,
+                angle=angle_fin,
+                start_angle=start_angle,
+                arc_center=inter,
+                **kwargs
+            )
+            if dot:
+                if dot_radius is None:
+                    dot_radius = radius / 10
+                else:
+                    self.dot_radius = dot_radius
+                right_dot = Dot(ORIGIN, radius=dot_radius, color=dot_color)
+                dot_anchor = (
+                    inter
+                    + (self.get_center() - inter)
+                    / np.linalg.norm(self.get_center() - inter)
+                    * radius
+                    * dot_distance
+                )
+                right_dot.move_to(dot_anchor)
+                self.add(right_dot)
+
+    def generate_points(self):
+        if self.elbow:
+            Elbow.generate_points(self)
+        else:
+            Arc.generate_points(self)
+
+
+class RightAngle(Angle):
+    """An elbow-type mobject representing a right angle between two lines.
+
+    Parameters
+    ----------
+    line1 : :class:`Line`
+        The first line.
+    line2 : :class:`Line`
+        The second line.
+    length : :class:`float`
+        The length of the arms.
+    **kwargs
+        Further keyword arguments that are passed to the constructor of :class:`Angle`.
+
+    Examples
+    --------
+
+    .. manim:: RightAngleExample
+        :save_last_frame:
+
+        class RightAngleExample(Scene):
+            def construct(self):
+                line1 = Line( LEFT, RIGHT )
+                line2 = Line( DOWN, UP )
+                rightangles = [
+                    RightAngle(line1, line2),
+                    RightAngle(line1, line2, length=0.4, quadrant=(1,-1)),
+                    RightAngle(line1, line2, length=0.5, quadrant=(-1,1), stroke_width=8),
+                    RightAngle(line1, line2, length=0.7, quadrant=(-1,-1), color=RED),
+                ]
+                line_list = VGroup( *[VGroup() for k in range(4)] )
+                for k in range(4):
+                    linea = line1.copy()
+                    lineb = line2.copy()
+                    line_list[k].add( linea )
+                    line_list[k].add( lineb )
+                    line_list[k].add( rightangles[k] )
+                line_list.arrange_in_grid(buff=1.5)
+                self.add(
+                    line_list
+                )
+
+    """
+
+    def __init__(self, line1, line2, length=None, **kwargs):
+        Angle.__init__(self, line1, line2, radius=length, elbow=True, **kwargs)
