@@ -1,17 +1,15 @@
+import typing
+import time
 import numpy as np
-from .. import config
-from ..utils.iterables import list_update
-from ..utils.exceptions import EndSceneEarlyException
-from ..scene.scene_file_writer import SceneFileWriter
-from ..utils.caching import handle_caching_play
+
+from manim.utils.hashing import get_hash_from_play_call
+
+from .. import config, logger
 from ..camera.camera import Camera
-
-
-def pass_scene_reference(func):
-    def wrapper(self, scene, *args, **kwargs):
-        func(self, scene, *args, **kwargs)
-
-    return wrapper
+from ..scene.scene_file_writer import SceneFileWriter
+from ..utils.exceptions import EndSceneEarlyException
+from ..utils.iterables import list_update
+from ..mobject.mobject import Mobject
 
 
 def handle_play_like_call(func):
@@ -35,7 +33,14 @@ def handle_play_like_call(func):
         to the video file stream.
     """
 
+    # NOTE : This is only kept for OpenGL renderer.
+    # The play logic of the cairo renderer as been refactored and does not need this function anymore.
+    # When OpenGL renderer will have a proper testing system,
+    # the play logic of the latter has to be refactored in the same way the cairo renderer has been, and thus this
+    # method has to be deleted.
+
     def wrapper(self, scene, *args, **kwargs):
+        self.animation_start_time = time.time()
         self.file_writer.begin_animation(not self.skip_animations)
         func(self, scene, *args, **kwargs)
         self.file_writer.end_animation(not self.skip_animations)
@@ -58,7 +63,7 @@ class CairoRenderer:
         self.file_writer = None
         camera_cls = camera_class if camera_class is not None else Camera
         self.camera = camera_cls()
-        self.original_skipping_status = skip_animations
+        self._original_skipping_status = skip_animations
         self.skip_animations = skip_animations
         self.animations_hashes = []
         self.num_plays = 0
@@ -71,12 +76,54 @@ class CairoRenderer:
             scene.__class__.__name__,
         )
 
-    @pass_scene_reference
-    @handle_caching_play
-    @handle_play_like_call
     def play(self, scene, *args, **kwargs):
-        if scene.compile_animation_data(*args, **kwargs):
+        # Reset skip_animations to the original state.
+        # Needed when rendering only some animations, and skipping others.
+        self.skip_animations = self._original_skipping_status
+        self.update_skipping_status()
+
+        scene.compile_animation_data(*args, **kwargs)
+
+        if self.skip_animations:
+            logger.debug(f"Skipping animation {self.num_plays}")
+            hash_current_animation = None
+        else:
+            if config["disable_caching"]:
+                logger.info("Caching disabled.")
+                hash_current_animation = f"uncached_{self.num_plays:05}"
+            else:
+                hash_current_animation = get_hash_from_play_call(
+                    scene, self.camera, scene.animations, scene.mobjects
+                )
+                if self.file_writer.is_already_cached(hash_current_animation):
+                    logger.info(
+                        f"Animation {self.num_plays} : Using cached data (hash : %(hash_current_animation)s)",
+                        {"hash_current_animation": hash_current_animation},
+                    )
+                    self.skip_animations = True
+        # adding None as a partial movie file will make file_writer ignore the latter.
+        self.file_writer.add_partial_movie_file(hash_current_animation)
+        self.animations_hashes.append(hash_current_animation)
+        logger.debug(
+            "List of the first few animation hashes of the scene: %(h)s",
+            {"h": str(self.animations_hashes[:5])},
+        )
+
+        # Save a static image, to avoid rendering non moving objects.
+        self.static_image = self.save_static_frame_data(scene, scene.static_mobjects)
+
+        self.file_writer.begin_animation(not self.skip_animations)
+        scene.begin_animations()
+        if scene.is_current_animation_frozen_frame():
+            self.update_frame(scene)
+            # self.duration stands for the total run time of all the animations.
+            # In this case, as there is only a wait, it will be the length of the wait.
+            self.freeze_current_frame(scene.duration)
+        else:
             scene.play_internal()
+        self.file_writer.end_animation(not self.skip_animations)
+
+        self.num_plays += 1
 
     def update_frame(  # TODO Description in Docstring
         self,
@@ -118,7 +165,7 @@ class CairoRenderer:
         kwargs["include_submobjects"] = include_submobjects
         self.camera.capture_mobjects(mobjects, **kwargs)
 
-    def render(self, scene, moving_mobjects):
+    def render(self, scene, time, moving_mobjects):
         self.update_frame(scene, moving_mobjects)
         self.add_frame(self.get_frame())
 
@@ -152,6 +199,20 @@ class CairoRenderer:
         for _ in range(num_frames):
             self.file_writer.write_frame(frame)
 
+    def freeze_current_frame(self, duration: float):
+        """Adds a static frame to the movie for a given duration. The static frame is the current frame.
+
+        Parameters
+        ----------
+        duration : float
+            [description]
+        """
+        dt = 1 / self.camera.frame_rate
+        self.add_frame(
+            self.get_frame(),
+            num_frames=int(duration / dt),
+        )
+
     def show_frame(self):
         """
         Opens the current frame in the Default Image Viewer
@@ -160,7 +221,27 @@ class CairoRenderer:
         self.update_frame(ignore_skipping=True)
         self.camera.get_image().show()
 
-    def save_static_frame_data(self, scene, static_mobjects):
+    def save_static_frame_data(
+        self, scene, static_mobjects: typing.Iterable[Mobject]
+    ) -> typing.Iterable[Mobject]:
+        """Compute and save the static frame, that will be reused at each frame to avoid to unecesseraly computer
+        static mobjects.
+
+        Parameters
+        ----------
+        scene : Scene
+            The scene played.
+        static_mobjects : typing.Iterable[Mobject]
+            Static mobjects of the scene. If None, self.static_image is set to None
+
+        Returns
+        -------
+        typing.Iterable[Mobject]
+            the static image computed.
+        """
+        if not static_mobjects:
+            self.static_image = None
+            return
         self.update_frame(scene, mobjects=static_mobjects)
         self.static_image = self.get_frame()
         return self.static_image
@@ -173,6 +254,8 @@ class CairoRenderer:
         the number of animations that need to be played, and
         raises an EndSceneEarlyException if they don't correspond.
         """
+        if config["save_last_frame"]:
+            self.skip_animations = True
         if config["from_animation_number"]:
             if self.num_plays < config["from_animation_number"]:
                 self.skip_animations = True
