@@ -77,6 +77,11 @@ __all__ = [
     "DARK_GRAY",
     "DARKER_GREY",
     "DARKER_GRAY",
+    "GREY_E",
+    "GREY_D",
+    "GREY_C",
+    "GREY_B",
+    "GREY_A",
     "GREY_BROWN",
     "PINK",
     "LIGHT_PINK",
@@ -183,6 +188,11 @@ class Colors(Enum):
     dark_gray = "#444444"
     darker_grey = "#222222"
     darker_gray = "#222222"
+    grey_e = "#222222"
+    grey_d = "#444444"
+    grey_c = "#888888"
+    grey_b = "#BBBBBB"
+    grey_a = "#DDDDDD"
     grey_brown = "#736357"
     pink = "#D147BD"
     light_pink = "#DC75CD"
@@ -252,6 +262,11 @@ DARK_GRAY = Colors.dark_gray.value
 DARKER_GREY = Colors.darker_gray.value
 DARKER_GRAY = Colors.darker_gray.value
 GREY_BROWN = Colors.grey_brown.value
+GREY_E = Colors.grey_e.value
+GREY_D = Colors.grey_d.value
+GREY_C = Colors.grey_c.value
+GREY_B = Colors.grey_b.value
+GREY_A = Colors.grey_a.value
 PINK = Colors.pink.value
 LIGHT_PINK = Colors.light_pink.value
 GREEN_SCREEN = Colors.green_screen.value
@@ -274,7 +289,7 @@ def color_to_rgba(color, alpha=1):
 def rgb_to_color(rgb):
     try:
         return Color(rgb=rgb)
-    except:
+    except Exception:
         return Color(WHITE)
 
 
